Module: Redis::Objects::ClassMethods

Defined in:
lib/redis/objects.rb

Overview

Class methods that appear in your class when you include Redis::Objects.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#redisObject

Returns the value of attribute redis.



77
78
79
# File 'lib/redis/objects.rb', line 77

def redis
  @redis
end

#redis_objectsObject

Returns the value of attribute redis_objects.



77
78
79
# File 'lib/redis/objects.rb', line 77

def redis_objects
  @redis_objects
end

Instance Method Details

#field_key(name, id = '') ⇒ Object

:nodoc:



89
90
91
92
# File 'lib/redis/objects.rb', line 89

def field_key(name, id='') #:nodoc:
  # This can never ever ever ever change or upgrades will corrupt all data
  @redis_objects[name.to_sym][:key] || "#{prefix}:#{id}:#{name}"
end

#prefixObject

:nodoc:



81
82
83
84
85
86
87
# File 'lib/redis/objects.rb', line 81

def prefix #:nodoc:
  @prefix ||= self.name.to_s.
    sub(%r{(.*::)}, '').
    gsub(/([A-Z]+)([A-Z][a-z])/,'\1_\2').
    gsub(/([a-z\d])([A-Z])/,'\1_\2').
    downcase
end

#prefix=(prefix) ⇒ Object

Set the Redis prefix to use. Defaults to model_name



80
# File 'lib/redis/objects.rb', line 80

def prefix=(prefix) @prefix = prefix end